package gui;

import model.ApprovalStatus;
import model.LeaveRequest;
import service.LeaveRequestService;
import service.ServiceFactory;

import javax.swing.*;
import java.awt.*;
import java.text.SimpleDateFormat;
import java.util.List;

public class RequestDetailDialog extends JDialog {
    private final LeaveRequestService leaveRequestService;
    private LeaveRequest currentRequest;

    public RequestDetailDialog(JFrame parent, String studentName) {
        super(parent, "请假详情", true);
        this.leaveRequestService = ServiceFactory.getLeaveRequestService();
        
        // 根据学生姓名获取请假信息
        List<LeaveRequest> requests = leaveRequestService.getAllLeaveRequests();
        this.currentRequest = requests.stream()
            .filter(r -> r.getStudent().getName().equals(studentName))
            .findFirst()
            .orElse(null);
        
        if (currentRequest == null) {
            JOptionPane.showMessageDialog(parent, "未找到请假信息！", "错误", JOptionPane.ERROR_MESSAGE);
            dispose();
            return;
        }
        
        setSize(500, 700);
        setLocationRelativeTo(parent);
        setResizable(false);
        
        initComponents();
    }

    private void initComponents() {
        // 主面板使用GridBagLayout
        JPanel mainPanel = new JPanel(new GridBagLayout());
        GridBagConstraints gbc = new GridBagConstraints();
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.fill = GridBagConstraints.HORIZONTAL;
        gbc.insets = new Insets(5, 10, 5, 10);

        SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

        // 学生基本信息
        addInfoField(mainPanel, gbc, "审核进度：", "班主任");
        addInfoField(mainPanel, gbc, "学院：", currentRequest.getStudent().getCollege());
        addInfoField(mainPanel, gbc, "专业：", currentRequest.getStudent().getMajor());
        addInfoField(mainPanel, gbc, "班级：", currentRequest.getStudent().getClassName());
        addInfoField(mainPanel, gbc, "姓名：", currentRequest.getStudent().getName());
        addInfoField(mainPanel, gbc, "学号：", currentRequest.getStudent().getStudentId());
        addInfoField(mainPanel, gbc, "手机号：", currentRequest.getStudent().getPhone());

        // 请假信息
        addInfoField(mainPanel, gbc, "申请外出时间：", dateFormat.format(currentRequest.getStartTime()));
        addInfoField(mainPanel, gbc, "预计返校时间：", dateFormat.format(currentRequest.getEndTime()));
        addInfoField(mainPanel, gbc, "时长：", String.format("%.2f", currentRequest.getDuration()));
        addInfoField(mainPanel, gbc, "外出地址：", currentRequest.getLocation());
        addInfoField(mainPanel, gbc, "外出事由：", currentRequest.getReasonType());
        addInfoField(mainPanel, gbc, "详细事由：", currentRequest.getReasonDetail());
        addInfoField(mainPanel, gbc, "是否离津：", currentRequest.isLeavingCity() ? "是" : "否");
        addInfoField(mainPanel, gbc, "其他特殊情况：", 
            currentRequest.getSpecialSituation() == null ? "" : currentRequest.getSpecialSituation());
        addInfoField(mainPanel, gbc, "发起时间：", dateFormat.format(currentRequest.getRequestTime()));

        // 如果已经审批过，显示审批信息
        if (currentRequest.getStatus() != ApprovalStatus.PENDING) {
            addInfoField(mainPanel, gbc, "审批状态：", currentRequest.getStatus().getDescription());
            if (currentRequest.getApprovalComment() != null) {
                addInfoField(mainPanel, gbc, "审批意见：", currentRequest.getApprovalComment());
            }
            if (currentRequest.getApprovalTime() != null) {
                addInfoField(mainPanel, gbc, "审批时间：", dateFormat.format(currentRequest.getApprovalTime()));
            }
        }

        // 审批按钮
        JPanel buttonPanel = new JPanel(new FlowLayout(FlowLayout.CENTER, 20, 10));
        JButton approveButton = new JButton("通过");
        JButton rejectButton = new JButton("驳回");
        
        // 如果已经审批过，禁用按钮
        if (currentRequest.getStatus() != ApprovalStatus.PENDING) {
            approveButton.setEnabled(false);
            rejectButton.setEnabled(false);
        }
        
        approveButton.setPreferredSize(new Dimension(100, 30));
        rejectButton.setPreferredSize(new Dimension(100, 30));
        
        // 设置按钮颜色
        approveButton.setBackground(new Color(39, 174, 96));
        approveButton.setForeground(Color.WHITE);
        rejectButton.setBackground(new Color(231, 76, 60));
        rejectButton.setForeground(Color.WHITE);
        
        buttonPanel.add(approveButton);
        buttonPanel.add(rejectButton);

        // 添加按钮面板
        gbc.insets = new Insets(20, 10, 10, 10);
        mainPanel.add(buttonPanel, gbc);

        // 添加事件监听
        approveButton.addActionListener(e -> {
            int result = JOptionPane.showConfirmDialog(
                this,
                "确定通过该请假申请吗？",
                "确认",
                JOptionPane.YES_NO_OPTION
            );
            if (result == JOptionPane.YES_OPTION) {
                leaveRequestService.approveLeaveRequest(
                    currentRequest.getId(),
                    ApprovalStatus.APPROVED,
                    "已通过"
                );
                dispose();
            }
        });

        rejectButton.addActionListener(e -> {
            String reason = JOptionPane.showInputDialog(
                this,
                "请输入驳回原因：",
                "驳回原因",
                JOptionPane.QUESTION_MESSAGE
            );
            if (reason != null && !reason.trim().isEmpty()) {
                leaveRequestService.approveLeaveRequest(
                    currentRequest.getId(),
                    ApprovalStatus.REJECTED,
                    reason
                );
                dispose();
            }
        });

        // 添加滚动面板
        JScrollPane scrollPane = new JScrollPane(mainPanel);
        scrollPane.setBorder(null);
        add(scrollPane);
    }

    private void addInfoField(JPanel panel, GridBagConstraints gbc, String label, String value) {
        JPanel fieldPanel = new JPanel(new BorderLayout(10, 0));
        
        JLabel labelComponent = new JLabel(label);
        labelComponent.setFont(new Font("微软雅黑", Font.BOLD, 12));
        
        JLabel valueComponent = new JLabel(value);
        valueComponent.setFont(new Font("微软雅黑", Font.PLAIN, 12));
        
        fieldPanel.add(labelComponent, BorderLayout.WEST);
        fieldPanel.add(valueComponent, BorderLayout.CENTER);
        
        panel.add(fieldPanel, gbc);
    }
}
