package service;

import dao.DAOFactory;
import dao.TeacherDAO;
import model.Teacher;
import java.util.List;

/**
 * 教师信息服务类
 */
public class TeacherService {
    private final TeacherDAO teacherDAO = DAOFactory.getTeacherDAO();

    /**
     * 添加教师
     * @param teacher 教师信息
     * @return 是否添加成功
     */
    public boolean addTeacher(Teacher teacher) {
        // 检查工号是否已存在
        if (teacherDAO.findByTeacherId(teacher.getTeacherId()) != null) {
            return false;
        }
        return teacherDAO.insert(teacher) > 0;
    }

    /**
     * 更新教师信息
     * @param teacher 教师信息
     * @return 是否更新成功
     */
    public boolean updateTeacher(Teacher teacher) {
        // 检查是否存在
        Teacher existingTeacher = teacherDAO.findById(teacher.getId());
        if (existingTeacher == null) {
            return false;
        }
        // 检查工号是否被其他教师使用
        Teacher teacherWithSameId = teacherDAO.findByTeacherId(teacher.getTeacherId());
        if (teacherWithSameId != null && teacherWithSameId.getId() != teacher.getId()) {
            return false;
        }
        return teacherDAO.update(teacher) > 0;
    }

    /**
     * 删除教师
     * @param id 教师ID
     * @return 是否删除成功
     */
    public boolean deleteTeacher(int id) {
        return teacherDAO.deleteById(id) > 0;
    }

    /**
     * 根据ID查询教师
     * @param id 教师ID
     * @return 教师信息
     */
    public Teacher getTeacherById(int id) {
        return teacherDAO.findById(id);
    }

    /**
     * 根据工号查询教师
     * @param teacherId 工号
     * @return 教师信息
     */
    public Teacher getTeacherByTeacherId(String teacherId) {
        return teacherDAO.findByTeacherId(teacherId);
    }

    /**
     * 查询所有教师
     * @return 教师列表
     */
    public List<Teacher> getAllTeachers() {
        return teacherDAO.findAll();
    }

    /**
     * 根据部门查询教师
     * @param department 部门名称
     * @return 教师列表
     */
    public List<Teacher> getTeachersByDepartment(String department) {
        return teacherDAO.findByDepartment(department);
    }

    /**
     * 根据姓名模糊查询教师
     * @param name 教师姓名
     * @return 教师列表
     */
    public List<Teacher> searchTeachersByName(String name) {
        return teacherDAO.findByNameLike(name);
    }
}
